@@ -3,7 +3,7 @@ use strict;
 use vars qw($VERSION);
 use base qw(Sys::Info::Driver::Unknown::Device::CPU::Env);
 
-$VERSION = '0.50';
+$VERSION = '0.60';
 
 BEGIN {
     local $SIG{__DIE__};
@@ -16,7 +16,7 @@ BEGIN {
     *_UPOK = sub {$UP};
 }
 
-sub load  {0}
+sub load {0}
 
 sub identify {
     my $self = shift;
@@ -24,22 +24,23 @@ sub identify {
 
     my @cpu;
     if ( _UPOK ) {
-        my $procs = Unix::Processors->new;
-        #$procs->max_online;
-        #$procs->max_clock;
-        #$procs->max_physical;
-        #if ($procs->max_online != $procs->max_physical) {
-        #    print "Hyperthreading between ",$procs->max_physical," physical CPUs.\n";
-        #}
-        foreach my $proc ( @{ $procs->processors } ) {
+        my $up = Unix::Processors->new;
+        foreach my $proc ( @{ $up->processors } ) {
             push @cpu, {
-                data_width    => undef,
-                address_width => undef,
-                bus_speed     => undef,
-                speed         => $proc->clock,
-                name          => $proc->type,
-                #id            => $proc->id,    #cpu id 0,1,2,3...
-                #state         => $proc->state, # online/offline/poweroff
+                processor_id                 => $proc->id, #cpu id 0,1,2,3...
+                data_width                   => undef,
+                address_width                => undef,
+                bus_speed                    => undef,
+                speed                        => $proc->clock,
+                name                         => $proc->type,
+                family                       => undef,
+                manufacturer                 => undef,
+                model                        => undef,
+                stepping                     => undef,
+                number_of_cores              => $up->max_physical,
+                number_of_logical_processors => $up->max_online,
+                L1_cache                     => undef,
+                flags                        => undef,
             };
         }
     } else {
@@ -60,13 +61,23 @@ Sys::Info::Driver::Unknown::Device::CPU - Compatibility layer for unsupported pl
 
 =head1 SYNOPSIS
 
-Nothing public here.
+-
 
 =head1 DESCRIPTION
 
-Nothing public here. L<Unix::Processors> is recommended for
+L<Unix::Processors> is recommended for
 unsupported platforms.
 
+=head1 METHODS
+
+=head2 identify
+
+See identify in L<Sys::Info::Device::CPU>.
+
+=head2 load
+
+See load in L<Sys::Info::Device::CPU>.
+
 =head1 SEE ALSO
 
 L<Sys::Info>, L<Sys::Info::CPU>, L<Unix::Processors>.
@@ -77,7 +88,7 @@ Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2006 Burak Grsoy. All rights reserved.
+Copyright 2006-2008 Burak Grsoy. All rights reserved.
 
 =head1 LICENSE
 
