@@ -1,15 +1,14 @@
 package Sys::Info::OS;
 use strict;
-use vars      qw( $VERSION @ISA );
-use Sys::Info qw(  OSID         );
+use vars      qw( $VERSION @ISA $AUTOLOAD );
+use Sys::Info qw( OSID _deprecate         );
+use base      qw( Sys::Info::Base         );
+use Carp      qw( croak                   );
 
-$VERSION = '0.50';
+$VERSION = '0.60';
 
 BEGIN {
-    # initial setup
-    my $class = 'Sys::Info::Driver::' . OSID . '::OS';
-    eval "require $class";
-    die  "Unable to load sub class $class. Error: $@" if $@;
+    my $class = __PACKAGE__->load_subclass('Sys::Info::Driver::%s::OS');
     push @ISA, $class;
 
     CREATE_SYNONYMS_AND_UTILITY_METHODS: {
@@ -21,7 +20,7 @@ BEGIN {
                     = *is_super_user
                     = *is_superuser
                     = *is_su
-                    = *{$class.'::is_root'}
+                    = *{ $class.'::is_root' }
                     ;
         *is_win32   = *is_windows
                     = *is_win
@@ -37,11 +36,13 @@ BEGIN {
     }
 
     CREATE_FAKES: {
+        # driver specific methods
         my @fakes = qw(
             is_winnt
             is_win95
             is_win9x
             product_type
+            cdkey
         );
 
         no strict qw(refs);
@@ -63,6 +64,19 @@ sub new {
     return $self;
 }
 
+sub meta {
+    my $self = shift;
+    my $id   = shift;
+    my %info = $self->SUPER::meta( $id );
+
+    return %info if ! $id;
+
+    my $lcid = lc $id;
+    croak "$id meta value is not supported" if ! exists $info{ $lcid };
+
+    return $info{ $lcid };
+}
+
 sub ip {
     my $self = shift;
     require Socket;
@@ -77,6 +91,49 @@ sub ip {
     return $ip;
 }
 
+# ------------------[ TO BE REMOVED
+
+sub AUTOLOAD {
+    my $self = shift;
+    my $name = $AUTOLOAD;
+       $name =~ s{.*:}{}xmsg;
+
+    if ( $name eq 'long_name' ) {
+        no strict qw(refs);
+        *{ $name } = sub {
+            _deprecate({
+                msg  => "Use \$os->name( long => 1 ) instead.",
+                name => "Sys::Info::OS::long_name",
+            });
+            my $self = shift;
+            my %opt  = @_ % 2 ? () : (@_);
+            $opt{long} = 1;
+            return $self->name( %opt );
+        };
+        return $self->$name( @_ );
+    }
+
+    if ( $name eq 'login_name_real' ) {
+        no strict qw(refs);
+        *{ $name } = sub {
+            _deprecate({
+                msg  => "Use \$os->login_name( real => 1 ) instead.",
+                name => "Sys::Info::OS::login_name_real",
+            });
+            my $self = shift;
+            my %opt  = @_ % 2 ? () : (@_);
+            $opt{real} = 1;
+            return $self->login_name( %opt );
+        };
+        return $self->$name( @_ );
+    }
+
+    my $class = ref($self) || $self;
+    die "Unable to locate $class method $name";
+}
+
+sub DESTROY {}
+
 1;
 
 __END__
@@ -110,7 +167,7 @@ Example:
    if($os->is_windows) {
       printf "This is a %s based system\n", $os->is_winnt ? 'NT' : '9.x';
    }
-   printf "Operating System: %s\n", $os->long_name;
+   printf "Operating System: %s\n", $os->name( long => 1 );
    
    my $user = $os->login_name_real || $os->login_name || 'User';
    print "$user, You've Got The P.O.W.E.R.!\n" if $os->is_root;
@@ -135,11 +192,15 @@ Object constructor.
 
 =head2 name
 
-Returns the OS name.
+Returns the OS name. Supports these named parameters: C<edition>, C<long>:
 
-=head2 long_name
+   # also include the edition info if present
+   $os->name( edition => 1 );
 
-Returns the long OS name (with build number, etc.).
+This will return the long OS name (with build number, etc.):
+
+   # also include the edition info if present
+   $os->name( long => 1, edition => 1 );
 
 =head2 version
 
@@ -176,11 +237,10 @@ Synonyms:
 
 =head2 login_name
 
-Returns the name of the effective user.
+Returns the name of the effective user. Supports parameters in
+C<< name => value >> format. Accepted parameters: C<real>:
 
-=head2 login_name_real
-
-Returns the real name of the effective user.
+    my $user = $os->login_name( real => 1 ) || $os->login_name;
 
 =head2 ip
 
@@ -189,7 +249,7 @@ Returns the IP number.
 =head2 fs
 
 Returns an info hash about the filesystem. The contents of the hash can
-vary between different systems.
+vary among different systems.
 
 =head2 host_name
 
@@ -202,6 +262,13 @@ vary between different systems.
 =head2 product_type
 
 
+=head2 meta
+
+Returns a hash containing various informations about the OS.
+
+=head2 cdkey
+
+
 
 =head1 UTILITY METHODS
 
@@ -293,7 +360,8 @@ I don't have any access to any other os, so this module
 
 =item *
 
-Win32::IsAdminUser() implemented in 5.8.4. If your ActivePerl
+Win32::IsAdminUser() implemented in 5.8.4 (However, it is possible to
+manually upgrade the C<Win32> module). If your ActivePerl
 is older than this, C<is_admin> method will always returns false.
 (There I<may> be a workaround for that).
 
